# Wild Drummer

Wild Drummer is an application that makes any sound sample into drum beats. 
Start playing with our [demo](https://onebotstudio.herokuapp.com/) by uploading a sample audio file.

## License
This project is licensed under the terms of the Apache-2.0 License - see the LICENSE.md file for details
